% Auto-generated chapter 43 for malik
% Hadiths in this chapter: 43

\hadithdefcmd{malik}{1552}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، أَنَّ فِي الْكِتَابِ الَّذِي، كَتَبَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَمْرِو بْنِ حَزْمٍ فِي الْعُقُولِ أَنَّ فِي النَّفْسِ مِائَةً مِنَ الإِبِلِ وَفِي الأَنْفِ إِذَا أُوعِيَ جَدْعًا مِائَةٌ مِنَ الإِبِلِ وَفِي الْمَأْمُومَةِ ثُلُثُ الدِّيَةِ وَفِي الْجَائِفَةِ مِثْلُهَا وَفِي الْعَيْنِ خَمْسُونَ وَفِي الْيَدِ خَمْسُونَ وَفِي الرِّجْلِ خَمْسُونَ وَفِي كُلِّ أُصْبُعٍ مِمَّا هُنَالِكَ عَشْرٌ مِنَ الإِبِلِ وَفِي السِّنِّ خَمْسٌ وَفِي الْمُوضِحَةِ خَمْسٌ ‏.‏\hadithno{1552}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from his father that in a letter which the Messenger of Allah, may Allah bless him and grant him peace, sent to Amr ibn Hazm about blood-money he wrote that it was one hundred camels for a life, one hundred camels for a nose if completely removed, a third of the blood-money for a wound in the brain, the same as that for a belly wound, fifty for an eye, fifty for a hand, fifty for a foot, ten camels for each finger, and five for teeth, and five for a head wound which laid bare the bone}}
\hadithdefcmd{malik}{1553}{حَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَوَّمَ الدِّيَةَ عَلَى أَهْلِ الْقُرَى فَجَعَلَهَا عَلَى أَهْلِ الذَّهَبِ أَلْفَ دِينَارٍ وَعَلَى أَهْلِ الْوَرِقِ اثْنَىْ عَشَرَ أَلْفَ دِرْهَمٍ ‏.‏ قَالَ مَالِكٌ فَأَهْلُ الذَّهَبِ أَهْلُ الشَّامِ وَأَهْلُ مِصْرَ وَأَهْلُ الْوَرِقِ أَهْلُ الْعِرَاقِ ‏.‏ وَحَدَّثَنِي يَحْيَى عَنْ مَالِكٍ أَنَّهُ سَمِعَ أَنَّ الدِّيَةَ تُقْطَعُ فِي ثَلاَثِ سِنِينَ أَوْ أَرْبَعِ سِنِينَ ‏.‏ قَالَ مَالِكٌ وَالثَّلاَثُ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّهُ لاَ يُقْبَلُ مِنْ أَهْلِ الْقُرَى فِي الدِّيَةِ الإِبِلُ وَلاَ مِنْ أَهْلِ الْعَمُودِ الذَّهَبُ وَلاَ الْوَرِقُ وَلاَ مِنْ أَهْلِ الذَّهَبِ الْوَرِقُ وَلاَ مِنْ أَهْلِ الْوَرِقِ الذَّهَبُ ‏.‏\hadithno{1553}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that Umar ibn al-Khattab estimated the full blood-money for the people of urban areas. For those who had gold, he made it one thousand dinars. and for those who had silver he made it ten thousand dirhams. Malik said, "The people of gold are the people of ash-Sham and the people of Egypt. The people of silver are the people of Iraq " Yahya related to me from Malik that he heard that the blood-money was divided into instalments over three or four years. Malik said, "Three is the most preferable to me of what I have heard on that." Malik said, "The generally agreed on way of doing things in our community is that camels are not accepted from the people of cities for blood-money nor is gold or silver accepted from the desert people. Silver is not accepted from the people of gold and gold is not accepted from the people of silver}}
\hadithdefcmd{malik}{1554}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّ ابْنَ شِهَابٍ، كَانَ يَقُولُ فِي دِيَةِ الْعَمْدِ إِذَا قُبِلَتْ خَمْسٌ وَعِشْرُونَ بِنْتَ مَخَاضٍ وَخَمْسٌ وَعِشْرُونَ بِنْتَ لَبُونٍ وَخَمْسٌ وَعِشْرُونَ حِقَّةً وَخَمْسُ وَعِشْرُونَ جَذَعَةً ‏.‏\hadithno{1554}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "The full blood-money for murder when it is accepted is twenty-five yearlings, twenty-five two-year-olds, twenty-five four-year-olds, and twenty-five five-year-olds}}
\hadithdefcmd{malik}{1555}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، كَتَبَ إِلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ أَنَّهُ أُتِيَ بِمَجْنُونٍ قَتَلَ رَجُلاً ‏.‏ فَكَتَبَ إِلَيْهِ مُعَاوِيَةُ أَنِ اعْقِلْهُ وَلاَ تُقِدْ مِنْهُ فَإِنَّهُ لَيْسَ عَلَى مَجْنُونٍ قَوَدٌ ‏.‏ قَالَ مَالِكٌ فِي الْكَبِيرِ وَالصَّغِيرِ إِذَا قَتَلاَ رَجُلاً جَمِيعًا عَمْدًا أَنَّ عَلَى الْكَبِيرِ أَنْ يُقْتَلَ وَعَلَى الصَّغِيرِ نِصْفُ الدِّيَةِ ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ الْحُرُّ وَالْعَبْدُ يَقْتُلاَنِ الْعَبْدَ فَيُقْتَلُ الْعَبْدُ وَيَكُونُ عَلَى الْحُرِّ نِصْفُ قِيمَتِهِ ‏.‏\hadithno{1555}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Marwan ibn al-Hakam wrote to Muawiya ibn Abi Sufyan that a madman was brought to him who had killed a man. Muawiya wrote to him, "Tie him up and do not inflict any retaliation on him. There is no retaliation against a madman." Malik said about an adult and a child when they murder a man together, "The adult is killed and the child pays half the full blood-money." Malik said, "It is like that with a freeman and a slave when they murder a slave. The slave is killed and the freeman pays half of his value}}
\hadithdefcmd{malik}{1556}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَجُلاً، مِنْ بَنِي سَعْدِ بْنِ لَيْثٍ أَجْرَى فَرَسًا فَوَطِئَ عَلَى إِصْبَعِ رَجُلٍ مِنْ جُهَيْنَةَ فَنُزِيَ مِنْهَا فَمَاتَ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ لِلَّذِي ادُّعِيَ عَلَيْهِمْ أَتَحْلِفُونَ بِاللَّهِ خَمْسِينَ يَمِينًا مَا مَاتَ مِنْهَا فَأَبَوْا وَتَحَرَّجُوا وَقَالَ لِلآخَرِينَ أَتَحْلِفُونَ أَنْتُمْ فَأَبَوْا فَقَضَى عُمَرُ بْنُ الْخَطَّابِ بِشَطْرِ الدِّيَةِ عَلَى السَّعْدِيِّينَ ‏.‏ قَالَ مَالِكٌ وَلَيْسَ الْعَمَلُ عَلَى هَذَا ‏.‏\hadithno{1556}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Irak ibn Malik and Sulayman ibn Yasar that a man of the Banu Sad ibn Layth was running a horse and it trod on the finger of a man from the Juhayna tribe. It bled profusely, and he died. Umar ibn al-Khattab said to those against whom the claim was made. "Do you swear by Allah with fifty oaths that he did not die of it?" They refused and stopped themselves from doing it. He said to the others, "Will you take an oath?" They refused, so Umar ibn al-Khattab gave a judgement that the Banu Sad had to pay half the full blood-money. Malik said, "One does not act on this}}
\hadithdefcmd{malik}{1557}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّ ابْنَ شِهَابٍ، وَسُلَيْمَانَ بْنَ يَسَارٍ، وَرَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ، كَانُوا يَقُولُونَ دِيَةُ الْخَطَإِ عِشْرُونَ بِنْتَ مَخَاضٍ وَعِشْرُونَ بِنْتَ لَبُونٍ وَعِشْرُونَ ابْنَ لَبُونٍ ذَكَرًا وَعِشْرُونَ حِقَّةً وَعِشْرُونَ جَذَعَةً ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّهُ لاَ قَوَدَ بَيْنَ الصِّبْيَانِ وَإِنَّ عَمْدَهُمْ خَطَأٌ مَا لَمْ تَجِبْ عَلَيْهِمُ الْحُدُودُ وَيَبْلُغُوا الْحُلُمَ وَإِنَّ قَتْلَ الصَّبِيِّ لاَ يَكُونُ إِلاَّ خَطَأً وَذَلِكَ لَوْ أَنَّ صَبِيًّا وَكَبِيرًا قَتَلاَ رَجُلاً حُرًّا خَطَأً كَانَ عَلَى عَاقِلَةِ كُلِّ وَاحِدٍ مِنْهُمَا نِصْفُ الدِّيَةِ ‏.‏ قَالَ مَالِكٌ وَمَنْ قَتَلَ خَطَأً فَإِنَّمَا عَقْلُهُ مَالٌ لاَ قَوَدَ فِيهِ وَإِنَّمَا هُوَ كَغَيْرِهِ مِنْ مَالِهِ يُقْضَى بِهِ دَيْنُهُ وَيُجَوَّزُ فِيهِ وَصِيَّتُهُ فَإِنْ كَانَ لَهُ مَالٌ تَكُونُ الدِّيَةُ قَدْرَ ثُلُثِهِ ثُمَّ عُفِيَ عَنْ دِيَتِهِ فَذَلِكَ جَائِزٌ لَهُ وَإِنْ لَمْ يَكُنْ لَهُ مَالٌ غَيْرُ دِيَتِهِ جَازَ لَهُ مِنْ ذَلِكَ الثُّلُثُ إِذَا عُفِيَ عَنْهُ وَأَوْصَى بِهِ ‏.‏\hadithno{1557}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab, Sulayman ibn Yasar, and Rabia ibn Abi Abd ar-Rahman said, "The blood-money of manslaughter is twenty yearlings, twenty two-year-olds, twenty male two-year-olds, twenty four-year-olds, and twenty five-year-olds." Malik said, "The generally agreed on way with us is that there is no retaliation against children. Their intention is accidental. The hudud are not obliged for them if they have not yet reached puberty. If a child kills someone it is only accidentally. Had a child and an adult killed a free man accidentally, each of them pays half the full blood-money." Malik said, "A person who kills someone accidentally pays blood-money with his property and there is no retaliation against him. That money is like anything else from the dead man's property and his debt is paid with it and he is allowed to make a bequest from it. If he has a total property of which the blood-money is a third and then the blood-money is relinquished, that is permitted to him. If all the property he has is his blood-money, he is permitted to relinquish a third of it and to make that a bequest}}
\hadithdefcmd{malik}{1558}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ تُعَاقِلُ الْمَرْأَةُ الرَّجُلَ إِلَى ثُلُثِ الدِّيَةِ إِصْبَعُهَا كَإِصْبَعِهِ وَسِنُّهَا كَسِنِّهِ وَمُوضِحَتُهَا كَمُوضِحَتِهِ وَمُنَقِّلَتُهَا كَمُنَقَّلَتِهِ ‏.‏\hadithno{1558}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that the generally agreed on way of doing things amongst the community about an accident is that there is no blood-money until the victim is better. If a man's bone, either a hand, or a foot, or another part of his body, is broken accidentally and it heals and becomes sound and returns to its form, there is no blood-money for it. If the limb is impaired or there is a scar on it, there is blood-money for it according to the extent that it is impaired. Malik said, "If that part of the body has a specific blood-money mentioned by the Prophet, may Allah bless him and grant him peace, it is according to what the Prophet, may Allah bless him and grant him peace, specified. If it is part of what does not have a specific blood-money for it mentioned by the Prophet, may Allah bless him and grant him peace, and if there is no previous sunna about it or specific blood-money, one uses ijtihad about it." Malik said, "There is no blood-money for an accidental bodily injury when the wound heals and returns to its form. If there is any scar or mark in that, ijtihad is used about it except for the belly-wound. There is a third of the blood-money of a life for it. " Malik said, "There is no blood-money for the wound which splinters a bone in the body, and it is like the wound to the body which lays bare the bone." Malik said, "The generally agreed on way of doing things in our community is that when the doctor performs a circumcision and cuts off the glans, he must pay the full blood-money. That is because it is an accident which the tribe is responsible for, and the full blood money is payable for all that in which a doctor errs or exceeds, when it is not intentional." Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "The blood-money for a woman is the same as for a man up to one third of the blood-money. Her finger is like his finger, her tooth is like his tooth, her injury which lays bare the bone is like his, and her head wound which splinters the bone is like his}}
\hadithdefcmd{malik}{1559}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، وَبَلَغَهُ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُمَا كَانَا يَقُولاَنِ مِثْلَ قَوْلِ سَعِيدِ بْنِ الْمُسَيَّبِ فِي الْمَرْأَةِ أَنَّهَا تُعَاقِلُ الرَّجُلَ إِلَى ثُلُثِ دِيَةِ الرَّجُلِ فَإِذَا بَلَغَتْ ثُلُثَ دِيَةِ الرَّجُلِ كَانَتْ إِلَى النِّصْفِ مِنْ دِيَةِ الرَّجُلِ ‏.‏ قَالَ مَالِكٌ وَتَفْسِيرُ ذَلِكَ أَنَّهَا تُعَاقِلُهُ فِي الْمُوضِحَةِ وَالْمُنَقَّلَةِ وَمَا دُونَ الْمَأْمُومَةِ وَالْجَائِفَةِ وَأَشْبَاهِهِمَا مِمَّا يَكُونُ فِيهِ ثُلُثُ الدِّيَةِ فَصَاعِدًا فَإِذَا بَلَغَتْ ذَلِكَ كَانَ عَقْلُهَا فِي ذَلِكَ النِّصْفَ مِنْ عَقْلِ الرَّجُلِ ‏.‏\hadithno{1559}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab and also Urwa ibn az-Zubayr said the same as Said ibn al-Musayyab said about a woman. Her blood-money from a man is the same up to a third of the blood-money of a man. If what she is owed exceeds a third of the blood-money of the man, she is given up to half of the blood-money of a man. Malik said, "The explanation of that is that she has blood-money for a head wound that lays bare the bone and one that splinters the bone and for what is less than the brain wound and the belly wound and the like of that of those which obliges a third of the blood-money or more. If the amount owed her exceeds that, her blood- money in that is half of the blood-money of a man}}
\hadithdefcmd{malik}{1560}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ مَضَتِ السُّنَّةُ أَنَّ الرَّجُلَ، إِذَا أَصَابَ امْرَأَتَهُ بِجُرْحٍ أَنَّ عَلَيْهِ عَقْلَ ذَلِكَ الْجُرْحِ وَلاَ يُقَادُ مِنْهُ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا ذَلِكَ فِي الْخَطَإِ أَنْ يَضْرِبَ الرَّجُلُ امْرَأَتَهُ فَيُصِيبَهَا مِنْ ضَرْبِهِ مَا لَمْ يَتَعَمَّدْ كَمَا يَضْرِبُهَا بِسَوْطٍ فَيَفْقَأُ عَيْنَهَا وَنَحْوَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ فِي الْمَرْأَةِ يَكُونُ لَهَا زَوْجٌ وَوَلَدٌ مِنْ غَيْرِ عَصَبَتِهَا وَلاَ قَوْمِهَا فَلَيْسَ عَلَى زَوْجِهَا إِذَا كَانَ مِنْ قَبِيلَةٍ أُخْرَى مِنْ عَقْلِ جِنَايَتِهَا شَىْءٌ وَلاَ عَلَى وَلَدِهَا إِذَا كَانُوا مِنْ غَيْرِ قَوْمِهَا وَلاَ عَلَى إِخْوَتِهَا مِنْ أُمِّهَا إِذَا كَانُوا مِنْ غَيْرِ عَصَبَتِهَا وَلاَ قَوْمِهَا فَهَؤُلاَءِ أَحَقُّ بِمِيرَاثِهَا وَالْعَصَبَةُ عَلَيْهِمُ الْعَقْلُ مُنْذُ زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الْيَوْمِ وَكَذَلِكَ مَوَالِي الْمَرْأَةِ مِيرَاثُهُمْ لِوَلَدِ الْمَرْأَةِ وَإِنْ كَانُوا مِنْ غَيْرِ قَبِيلَتِهَا وَعَقْلُ جِنَايَةِ الْمَوَالِي عَلَى قَبِيلَتِهَا ‏.‏\hadithno{1560}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Ibn Shihab say, "The precedent of the sunna when a man injures a woman is that he must pay the blood- money for that injury and there is no retaliation against him." Malik said, "That is an accidental injury, when a man strikes a woman and hits with a blow what he did not intend, for instance, if he struck her with a whip and cut her eye open and the like of that." Malik said about a woman who has a husband and children who are not from her paternal relatives or her people, that since he is from another tribe, there is no blood-money against her husband for her criminal action, nor any against her children if they are not from her people, nor any against her maternal brothers when they are not from her paternal relations or her people. These are entitled to her inheritance but only the paternal relations have paid blood-money from since the time of the Messenger of Allah, may Allah bless him and grant him peace. Until today it is like that with the mawla of a woman. The inheritance they leave goes to the children of the woman even if they are not from her tribe, but the blood-money of the criminal act of the mawla is only against her tribe}}
\hadithdefcmd{malik}{1561}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ امْرَأَتَيْنِ، مِنْ هُذَيْلٍ رَمَتْ إِحْدَاهُمَا الأُخْرَى فَطَرَحَتْ جَنِينَهَا فَقَضَى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ ‏.‏\hadithno{1561}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Salama ibn Abd ar-Rahman ibn Awf from Abu Hurayra that a woman from the Hudhayl tribe threw a stone at a woman from the same tribe, and she had a miscarriage. The Messenger of Allah, may Allah bless him and grant him peace, gave a judgement that a slave or slave-girl of fair complexion and excellence should be given to her}}
\hadithdefcmd{malik}{1562}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي الْجَنِينَ يُقْتَلُ فِي بَطْنِ أُمِّهِ بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ فَقَالَ الَّذِي قُضِيَ عَلَيْهِ كَيْفَ أَغْرَمُ مَا لاَ شَرِبَ وَلاَ أَكَلْ وَلاَ نَطَقَ وَلاَ اسْتَهَلّ وَمِثْلُ ذَلِكَ بَطَلْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏ ‏.‏\hadithno{1562}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, gave a judgement that the compensation for a foetus killed in its mother's womb was a slave or slave-girl of fair complexion and excellence. The one against whom the judgement was given said, "Why should I pay damages for that which did not drink or eat or speak or make any cry. The like of that is nothing." The Messenger of Allah, may Allah bless him and grant him peace, said, "This is only one of the brothers of the diviners." He disapproved of the rhyming speech of the man's declaration}}
\hadithdefcmd{malik}{1563}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ كَانَ يَقُولُ الْغُرَّةُ تُقَوَّمُ خَمْسِينَ دِينَارًا أَوْ سِتَّمِائَةِ دِرْهَمٍ وَدِيَةُ الْمَرْأَةِ الْحُرَّةِ الْمُسْلِمَةِ خَمْسُمِائَةِ دِينَارٍ أَوْ سِتَّةُ آلاَفِ دِرْهَمٍ ‏.‏ قَالَ مَالِكٌ فَدِيَةُ جَنِينِ الْحُرَّةِ عُشْرُ دِيَتِهَا وَالْعُشْرُ خَمْسُونَ دِينَارًا أَوْ سِتُّمِائَةِ دِرْهَمٍ ‏.‏ قَالَ مَالِكٌ وَلَمْ أَسْمَعْ أَحَدًا يُخَالِفُ فِي أَنَّ الْجَنِينَ لاَ تَكُونُ فِيهِ الْغُرَّةُ حَتَّى يُزَايِلَ بَطْنَ\hadithno{1563}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Rabia ibn Abi Abd ar-Rahman said, "The slave of fair complexion and excellence is estimated at fifty dinars or six hundred dirhams. The blood-money of a free muslim woman is five hundred dinars or six thousand dirhams." Malik said, "The blood-money of the foetus of a free woman is a tenth of her blood-money. The tenth is fifty dinars or six hundred dirhams." Malik said, "I have not heard anyone dispute that there is no slave in compensation for the foetus until it leaves its mother's womb and falls still-born from her womb . " Malik said, "I heard that if the foetus comes out of its mother's womb alive and then dies, the full blood-money is due for it." Malik said, "The foetus is not alive unless it cries at birth. If it comes out of its mother's womb and cries out and then dies, the complete blood-money is due for it. We think that the slave- girl's foetus has a tenth of the price of the slave-girl." Malik said, "When a woman murders a man or woman, and the murderess is pregnant, retaliation is not taken against her until she has given birth. If a woman who is pregnant is killed intentionally or unintentionally, the one who killed her is not obliged to pay anything for her foetus. If she is murdered, then the one who killed her is killed and there is no blood-money for her foetus. If she is killed accidentally, the tribe obliged to pay on behalf of her killer pays her blood-money, and there is no blood-money for the foetus." Yahya related to me, "Malik was asked about the foetus of the christian or jewish woman which was aborted. He said, 'I think that there is a tenth of the blood-money of the mother for it}}
\hadithdefcmd{malik}{1564}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ فِي الشَّفَتَيْنِ الدِّيَةُ كَامِلَةً فَإِذَا قُطِعَتِ السُّفْلَى فَفِيهَا ثُلُثَا الدِّيَةِ ‏.‏\hadithno{1564}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab used to say, "The full blood-money is payable for cutting off both lips, but when the lower one only is cut off, two-thirds of the blood-money is due for it}}
\hadithdefcmd{malik}{1565}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الرَّجُلِ الأَعْوَرِ، يَفْقَأُ عَيْنَ الصَّحِيحِ فَقَالَ ابْنُ شِهَابٍ إِنْ أَحَبَّ الصَّحِيحُ أَنْ يَسْتَقِيدَ، مِنْهُ فَلَهُ الْقَوَدُ وَإِنْ أَحَبَّ فَلَهُ الدِّيَةُ أَلْفُ دِينَارٍ أَوِ اثْنَا عَشَرَ أَلْفَ دِرْهَمٍ ‏.‏ وَحَدَّثَنِي يَحْيَى عَنْ مَالِكٍ أَنَّهُ بَلَغَهُ أَنَّ فِي كُلِّ زَوْجٍ مِنَ الإِنْسَانِ الدِّيَةَ كَامِلَةً وَأَنَّ فِي اللِّسَانِ الدِّيَةَ كَامِلَةً وَأَنَّ فِي الأُذُنَيْنِ إِذَا ذَهَبَ سَمْعُهُمَا الدِّيَةَ كَامِلَةً اصْطُلِمَتَا أَوْ لَمْ تُصْطَلَمَا وَفِي ذَكَرِ الرَّجُلِ الدِّيَةُ كَامِلَةً وَفِي الأُنْثَيَيْنِ الدِّيَةُ كَامِلَةً ‏.‏ وَحَدَّثَنِي يَحْيَى عَنْ مَالِكٍ أَنَّهُ بَلَغَهُ أَنَّ فِي ثَدْيَىِ الْمَرْأَةِ الدِّيَةَ كَامِلَةً ‏.‏ قَالَ مَالِكٌ وَأَخَفُّ ذَلِكَ عِنْدِي الْحَاجِبَانِ وَثَدْيَا الرَّجُلِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّ الرَّجُلَ إِذَا أُصِيبَ مِنْ أَطْرَافِهِ أَكْثَرُ مِنْ دِيَتِهِ فَذَلِكَ لَهُ إِذَا أُصِيبَتْ يَدَاهُ وَرِجْلاَهُ وَعَيْنَاهُ فَلَهُ ثَلاَثُ دِيَاتٍ ‏.‏ قَالَ مَالِكٌ فِي عَيْنِ الأَعْوَرِ الصَّحِيحَةِ إِذَا فُقِئَتْ خَطَأً إِنَّ فِيهَا الدِّيَةَ كَامِلَةً ‏.‏\hadithno{1565}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he asked Ibn Shihab about the one-eyed man who gouged out the eye of a healthy person. Ibn Shihab said, "If the healthy person wants to take retaliation from him, he can have his retaliation. If he prefers, he has blood-money of one thousand dinars, twelve thousand dirhams." Yahya related to me from Malik that he heard that full blood- money was payable for both of a pair of anything in a man that occurred in pairs, and the tongue had full blood-money. The ears, when their hearing departed, had full blood-money, whether or not they were cut off, and a man's penis had full blood-money and the testicles had full blood-money. Yahya related to me from Malik that he heard that the breasts of a woman had full blood-money. Malik said, "The least of that are the eyebrows and a man's breasts." Malik said, "What is done in our community when a man is injured in his extremities to an extent that obliges payment of more than the amount of his full blood-money, is that it is his right. If his hands, feet, and eyes are all injured, he has three full blood-moneys." Malik said about the sound eye of a one-eyed man when it is accidentally gouged out, "The full blood-money is payable for it}}
\hadithdefcmd{malik}{1566}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، كَانَ يَقُولُ فِي الْعَيْنِ الْقَائِمَةِ إِذَا طَفِئَتْ مِائَةُ دِينَارٍ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنْ شَتَرِ الْعَيْنِ وَحِجَاجِ الْعَيْنِ فَقَالَ لَيْسَ فِي ذَلِكَ إِلاَّ الاِجْتِهَادُ إِلاَّ أَنْ يَنْقُصَ بَصَرُ الْعَيْنِ فَيَكُونُ لَهُ بِقَدْرِ مَا نَقَصَ مِنْ بَصَرِ الْعَيْنِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الْعَيْنِ الْقَائِمَةِ الْعَوْرَاءِ إِذَا طَفِئَتْ وَفِي الْيَدِ الشَّلاَّءِ إِذَا قُطِعَتْ إِنَّهُ لَيْسَ فِي ذَلِكَ إِلاَّ الاِجْتِهَادُ وَلَيْسَ فِي ذَلِكَ عَقْلٌ مُسَمًّى ‏.‏\hadithno{1566}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Sulayman ibn Yasar that Zayd ibn Thabit used to say, "When the eye remains but the sight is lost, one hundred dinars are payable for it." Yahya said, "Malik was asked about cutting off the lower lid of the eye and the bone around the eye. He said, 'There is only ijtihad in that unless the vision of the eye is impaired. He is entitled to an amount that is compatible to the extent the vision of the eye has been impaired." Yahya said that Malik said, "What is done in our community about removing the bad eye of a one-eyed man when it has already been blinded and still remains there in its place and the paralyzed hand when it is cut off, is that there is only ijtihad in that, and there is no prescribed blood-money}}
\hadithdefcmd{malik}{1567}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سُلَيْمَانَ بْنَ يَسَارٍ، يَذْكُرُ أَنَّ الْمُوضِحَةَ، فِي الْوَجْهِ مِثْلُ الْمُوضِحَةِ فِي الرَّأْسِ إِلاَّ أَنْ تَعِيبَ الْوَجْهَ فَيُزَادُ فِي عَقْلِهَا مَا بَيْنَهَا وَبَيْنَ عَقْلِ نِصْفِ الْمُوضِحَةِ فِي الرَّأْسِ فَيَكُونُ فِيهَا خَمْسَةٌ وَسَبْعُونَ دِينَارًا ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا أَنَّ فِي الْمُنَقَّلَةِ خَمْسَ عَشْرَةَ فَرِيضَةً ‏.‏ قَالَ وَالْمُنَقَّلَةُ الَّتِي يَطِيرُ فِرَاشُهَا مِنَ الْعَظْمِ وَلاَ تَخْرِقُ إِلَى الدِّمَاغِ وَهِيَ تَكُونُ فِي الرَّأْسِ وَفِي الْوَجْهِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّ الْمَأْمُومَةَ وَالْجَائِفَةَ لَيْسَ فِيهِمَا قَوَدٌ ‏.‏ وَقَدْ قَالَ ابْنُ شِهَابٍ لَيْسَ فِي الْمَأْمُومَةِ قَوَدٌ ‏.‏ قَالَ مَالِكٌ وَالْمَأْمُومَةُ مَا خَرَقَ الْعَظْمَ إِلَى الدِّمَاغِ وَلاَ تَكُونُ الْمَأْمُومَةُ إِلاَّ فِي الرَّأْسِ وَمَا يَصِلُ إِلَى الدِّمَاغِ إِذَا خَرَقَ الْعَظْمَ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّهُ لَيْسَ فِيمَا دُونَ الْمُوضِحَةِ مِنَ الشِّجَاجِ عَقْلٌ حَتَّى تَبْلُغَ الْمُوضِحَةَ وَإِنَّمَا الْعَقْلُ فِي الْمُوضِحَةِ فَمَا فَوْقَهَا وَذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْتَهَى إِلَى الْمُوضِحَةِ فِي كِتَابِهِ لِعَمْرِو بْنِ حَزْمٍ فَجَعَلَ فِيهَا خَمْسًا مِنَ الإِبِلِ وَلَمْ تَقْضِ الأَئِمَّةُ فِي الْقَدِيمِ وَلاَ فِي الْحَدِيثِ فِيمَا دُونَ الْمُوضِحَةِ بِعَقْلٍ ‏.‏\hadithno{1567}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard Sulayman ibn Yasar mention that a face wound in which the bone was bared was like a head wound in which the bone was bared, unless the face was scarred by the wound. Then the blood-money is increased by one half of the blood-money of the head wound in which the skin was bared so that seventy five dinars are payable for it. Malik said, "What is done in our community is that the head wound with splinters has fifteen camels." He explained, "The head wound with splinters is that from which pieces of bone fly off and which does not reach the brain. It can be in the head or the face." Malik said, "The generally agreed on way of doing things in our community, is that there is no retaliation for a wound to the brain or a belly wound, and Ibn Shihab has said, 'There is no retaliation for a wound to the brain.' " Malik explained, "The wound to the brain is what pierces the bones to the brain. This type of wound only occurs in the head. It is that which reaches the brain when the bones are pierced." Malik said, "What is done in our community is that there is no blood-money paid on any head wound less than one which lays bare the skull. Blood-money is payable only for the head wound that bares the bone and what is worse than that. That is because the Messenger of Allah, may Allah bless him and grant him peace, stopped at the head wound which bared the bone in his letter to Amr ibn Hazm. He made it five camels. The imams, past and present, have not made any blood- money payable for injuries less than the head wound which bares the bone}}
\hadithdefcmd{malik}{1568}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ كُلُّ نَافِذَةٍ فِي عُضْوٍ مِنَ الأَعْضَاءِ فَفِيهَا ثُلُثُ عَقْلِ ذَلِكَ الْعُضْوِ ‏.‏\hadithno{1568}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said, that Said ibn al-Musayyab said, "For every piercing wound in any of the organs or limbs of the body, one third of the blood-money of that limb is payable}}
\hadithdefcmd{malik}{1569}{حَدَّثَنِي مَالِكٌ، كَانَ ابْنُ شِهَابٍ لاَ يَرَى ذَلِكَ وَأَنَا لاَ، أَرَى فِي نَافِذَةٍ فِي عُضْوٍ مِنَ الأَعْضَاءِ فِي الْجَسَدِ أَمْرًا مُجْتَمَعًا عَلَيْهِ وَلَكِنِّي أَرَى فِيهَا الاِجْتِهَادَ يَجْتَهِدُ الإِمَامُ فِي ذَلِكَ وَلَيْسَ فِي ذَلِكَ أَمْرٌ مُجْتَمَعٌ عَلَيْهِ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّ الْمَأْمُومَةَ وَالْمُنَقَّلَةَ وَالْمُوضِحَةَ لاَ تَكُونُ إِلاَّ فِي الْوَجْهِ وَالرَّأْسِ فَمَا كَانَ فِي الْجَسَدِ مِنْ ذَلِكَ فَلَيْسَ فِيهِ إِلاَّ الاِجْتِهَادُ ‏.‏ قَالَ مَالِكٌ فَلاَ أَرَى اللَّحْىَ الأَسْفَلَ وَالأَنْفَ مِنَ الرَّأْسِ فِي جِرَاحِهِمَا لأَنَّهُمَا عَظْمَانِ مُنْفَرِدَانِ وَالرَّأْسُ بَعْدَهُمَا عَظْمٌ وَاحِدٌ ‏.‏\hadithno{1569}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me, "Ibn Shihab did not think and nor do I, that there is a generally agreed on way of doing things regarding a piercing wound in any of the organs or limbs of the body, but I think that there is ijtihad in the case. The imam uses ijtihad in it, and there is no generally agreed on way of doing things in our community about it." Malik said, "What is done in our community about the wound to the brain and the wound which splinters the bone, and the wound that bares the bone is that they apply only to the head and face. Whatever of that occurs in the body only has ijtihad in it." Malik said, "I do not think the lower jaw and the nose are part of the head in their injury because they are separate bones, and except for them the head is one bone}}
\hadithdefcmd{malik}{1570}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، أَقَادَ مِنَ الْمُنَقَّلَةِ ‏.‏\hadithno{1570}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that Abdullah ibn az-Zubayr allowed retaliation for a head wound which splintered the bone}}
\hadithdefcmd{malik}{1571}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ سَأَلْتُ سَعِيدَ بْنَ الْمُسَيَّبِ كَمْ فِي إِصْبَعِ الْمَرْأَةِ فَقَالَ عَشْرٌ مِنَ الإِبِلِ ‏.‏ فَقُلْتُ كَمْ فِي إِصْبَعَيْنِ قَالَ عِشْرُونَ مِنَ الإِبِلِ ‏.‏ فَقُلْتُ كَمْ فِي ثَلاَثٍ فَقَالَ ثَلاَثُونَ مِنَ الإِبِلِ ‏.‏ فَقُلْتُ كَمْ فِي أَرْبَعٍ قَالَ عِشْرُونَ مِنَ الإِبِلِ ‏.‏ فَقُلْتُ حِينَ عَظُمَ جُرْحُهَا وَاشْتَدَّتْ مُصِيبَتُهَا نَقَصَ عَقْلُهَا فَقَالَ سَعِيدٌ أَعِرَاقِيٌّ أَنْتَ فَقُلْتُ بَلْ عَالِمٌ مُتَثَبِّتٌ أَوْ جَاهِلٌ مُتَعَلِّمٌ ‏.‏ فَقَالَ سَعِيدٌ هِيَ السُّنَّةُ يَا ابْنَ أَخِي ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي أَصَابِعِ الْكَفِّ إِذَا قُطِعَتْ فَقَدْ تَمَّ عَقْلُهَا وَذَلِكَ أَنَّ خَمْسَ الأَصَابِعِ إِذَا قُطِعَتْ كَانَ عَقْلُهَا عَقْلَ الْكَفِّ خَمْسِينَ مِنَ الإِبِلِ فِي كُلِّ إِصْبَعٍ عَشَرَةٌ مِنَ الإِبِلِ ‏.‏ قَالَ مَالِكٌ وَحِسَابُ الأَصَابِعِ ثَلاَثَةٌ وَثَلاَثُونَ دِينَارٍ وَثُلُثُ دِينَارٍ فِي كُلِّ أَنْمُلَةٍ وَهِيَ مِنَ الإِبِلِ ثَلاَثُ فَرَائِضَ وَثُلُثُ فَرِيضَةٍ ‏.‏\hadithno{1571}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{ibn Abi Abd ar-Rahman said, "I asked Said ibn al Musayyab, 'How much for the finger of a woman?' He said, 'Ten camels' I said, 'How much for two fingers?' He said, 'Twenty camels.' I said, 'How much for three?' He said, 'Thirty camels.' I said, 'How much for four?' He said, 'Twenty camels.' I said, 'When her wound is greater and her affliction stronger, is her blood-money then less?' He said, 'Are you an Iraqi?' I said, 'Rather, I am a scholar who seeks to verify things, or an ignorant man who seeks to learn.' Said said, 'It is the sunna, my nephew.' " Malik said, "What is done in our community about all the fingers of the hand being cut off is that its blood- money is complete. That is because when five fingers are cut, their blood-money is the blood-money of the hand:fifty camels. Each finger has ten camels." Malik said, "The reckoning of the fingers is thirty-three dinars for each fingertip, and that is three and a third shares of camels}}
\hadithdefcmd{malik}{1572}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ مُسْلِمِ بْنِ جُنْدُبٍ، عَنْ أَسْلَمَ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَضَى فِي الضِّرْسِ بِجَمَلٍ وَفِي التَّرْقُوَةِ بِجَمَلٍ وَفِي الضِّلَعِ بِجَمَلٍ ‏.‏\hadithno{1572}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Muslim ibn Jundub from Aslam, the mawla of Umar ibn al-Khattab that Umar ibn al-Khattab decided on a camel for a molar, a camel for a collar-bone, and a camel for a rib}}
\hadithdefcmd{malik}{1573}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَضَى عُمَرُ بْنُ الْخَطَّابِ فِي الأَضْرَاسِ بِبَعِيرٍ بَعِيرٍ وَقَضَى مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ فِي الأَضْرَاسِ بِخَمْسَةِ أَبْعِرَةٍ خَمْسَةِ أَبْعِرَةٍ ‏.‏ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ فَالدِّيَةُ تَنْقُصُ فِي قَضَاءِ عُمَرَ بْنِ الْخَطَّابِ وَتَزِيدُ فِي قَضَاءِ مُعَاوِيَةَ فَلَوْ كُنْتُ أَنَا لَجَعَلْتُ فِي الأَضْرَاسِ بَعِيرَيْنِ بَعِيرَيْنِ فَتِلْكَ الدِّيَةُ سَوَاءٌ وَكُلُّ مُجْتَهِدٍ مَأْجُورٌ ‏.‏\hadithno{1573}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard Said ibn al-Musayyab say, ''Umar ibn al-Khattab decided on a camel for each molar, and Muawiya ibn Abi Sufyan decided on five camels for each molar." Said ibn al-Musayyab said, "The blood-money is less in the judgement of Umar ibn al-Khattab and more in the judgement of Muawiya. Had it been me, I would have made it two camels for each molar. That is the fair blood-money, and every one who strives with ijtihad is rewarded}}
\hadithdefcmd{malik}{1574}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ إِذَا أُصِيبَتِ السِّنُّ فَاسْوَدَّتْ فَفِيهَا عَقْلُهَا تَامًّا فَإِنْ طُرِحَتْ بَعْدَ أَنْ تَسْوَدَّ فَفِيهَا عَقْلُهَا أَيْضًا تَامًّا ‏.‏\hadithno{1574}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab used to say,' 'When a tooth is struck and becomes black, there is complete blood- money for it. If it falls out after it becomes black, there is also the complete blood-money for it}}
\hadithdefcmd{malik}{1575}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي غَطَفَانَ بْنِ طَرِيفٍ الْمُرِّيِّ، أَنَّهُ أَخْبَرَهُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ بَعَثَهُ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ يَسْأَلُهُ مَاذَا فِي الضِّرْسِ فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ فِيهِ خَمْسٌ مِنَ الإِبِلِ ‏.‏ قَالَ فَرَدَّنِي مَرْوَانُ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقَالَ أَتَجْعَلُ مُقَدَّمَ الْفَمِ مِثْلَ الأَضْرَاسِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ لَوْ لَمْ تَعْتَبِرْ ذَلِكَ إِلاَّ بِالأَصَابِعِ عَقْلُهَا سَوَاءٌ ‏.‏\hadithno{1575}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn that Abu Ghatafan ibn Tarif al-Murri informed him that Marwan ibn al-Hakam sent him to Abdullah ibn Abbas to ask him what there was for the molar. Abdullah ibn Abbas said, "There are five camels for it." He said, "Marwan sent me back again to Abdullah ibn Abbas.'' He said, "Do you make front teeth like molars?" Abdullah ibn Abbas said, "It is enough that you take the fingers as the example for that, their blood-moneys being all the same}}
\hadithdefcmd{malik}{1576}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُسَوِّي بَيْنَ الأَسْنَانِ فِي الْعَقْلِ وَلاَ يُفَضِّلُ بَعْضَهَا عَلَى بَعْضٍ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا أَنَّ مُقَدَّمَ الْفَمِ وَالأَضْرَاسِ وَالأَنْيَابِ عَقْلُهَا سَوَاءٌ وَذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي السِّنِّ خَمْسٌ مِنَ الإِبِلِ ‏"‏ ‏.‏ وَالضِّرْسُ سِنٌّ مِنَ الأَسْنَانِ لاَ يَفْضُلُ بَعْضُهَا عَلَى بَعْضٍ ‏.‏\hadithno{1576}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father made all the teeth the same in the blood-money and did not prefer any kind over others. Malik said, "What is done in our community is that the front teeth, molars, and eye-teeth have the same blood-money. That is because the Messenger of Allah, may Allah bless him and grant him peace, said, 'The tooth has five camels.' The molar is one of the teeth and he did not prefer any kind over the others}}
\hadithdefcmd{malik}{1577}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، كَانَا يَقُولاَنِ فِي مُوضِحَةِ الْعَبْدِ نِصْفُ عُشْرِ ثَمَنِهِ ‏.‏\hadithno{1577}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar said, "The head wound of the slave in which the bone is bared is a twentieth of his price}}
\hadithdefcmd{malik}{1578}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، كَانَ يَقْضِي فِي الْعَبْدِ يُصَابُ بِالْجِرَاحِ أَنَّ عَلَى مَنْ جَرَحَهُ قَدْرَ مَا نَقَصَ مِنْ ثَمَنِ الْعَبْدِ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا أَنَّ فِي مُوضِحَةِ الْعَبْدِ نِصْفَ عُشْرِ ثَمَنِهِ وَفِي مُنَقَّلَتِهِ الْعُشْرُ وَنِصْفُ الْعُشْرِ مِنْ ثَمَنِهِ وَفِي مَأْمُومَتِهِ وَجَائِفَتِهِ فِي كُلِّ وَاحِدَةٍ مِنْهُمَا ثُلُثُ ثَمَنِهِ وَفِيمَا سِوَى هَذِهِ الْخِصَالِ الأَرْبَعِ مِمَّا يُصَابُ بِهِ الْعَبْدُ مَا نَقَصَ مِنْ ثَمَنِهِ يُنْظَرُ فِي ذَلِكَ بَعْدَ مَا يَصِحُّ الْعَبْدُ وَيَبْرَأُ كَمْ بَيْنَ قِيمَةِ الْعَبْدِ بَعْدَ أَنْ أَصَابَهُ الْجُرْحُ وَقِيمَتِهِ صَحِيحًا قَبْلَ أَنْ يُصِيبَهُ هَذَا ثُمَّ يَغْرَمُ الَّذِي أَصَابَهُ مَا بَيْنَ الْقِيمَتَيْنِ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ إِذَا كُسِرَتْ يَدُهُ أَوْ رِجْلُهُ ثُمَّ صَحَّ كَسْرُهُ فَلَيْسَ عَلَى مَنْ أَصَابَهُ شَىْءٌ فَإِنْ أَصَابَ كَسْرَهُ ذَلِكَ نَقْصٌ أَوْ عَثَلٌ كَانَ عَلَى مَنْ أَصَابَهُ قَدْرُ مَا نَقَصَ مِنْ ثَمَنِ الْعَبْدِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الْقِصَاصِ بَيْنَ الْمَمَالِيكِ كَهَيْئَةِ قِصَاصِ الأَحْرَارِ نَفْسُ الأَمَةِ بِنَفْسِ الْعَبْدِ وَجُرْحُهَا بِجُرْحِهِ فَإِذَا قَتَلَ الْعَبْدُ عَبْدًا عَمْدًا خُيِّرَ سَيِّدُ الْعَبْدِ الْمَقْتُولِ فَإِنْ شَاءَ قَتَلَ وَإِنْ شَاءَ أَخَذَ الْعَقْلَ فَإِنْ أَخَذَ الْعَقْلَ أَخَذَ قِيمَةَ عَبْدِهِ وَإِنْ شَاءَ رَبُّ الْعَبْدِ الْقَاتِلِ أَنْ يُعْطِيَ ثَمَنَ الْعَبْدِ الْمَقْتُولِ فَعَلَ وَإِنْ شَاءَ أَسْلَمَ عَبْدَهُ فَإِذَا أَسْلَمَهُ فَلَيْسَ عَلَيْهِ غَيْرُ ذَلِكَ وَلَيْسَ لِرَبِّ الْعَبْدِ الْمَقْتُولِ إِذَا أَخَذَ الْعَبْدَ الْقَاتِلَ وَرَضِيَ بِهِ أَنْ يَقْتُلَهُ وَذَلِكَ فِي الْقِصَاصِ كُلِّهِ بَيْنَ الْعَبِيدِ فِي قَطْعِ الْيَدِ وَالرِّجْلِ وَأَشْبَاهِ ذَلِكَ بِمَنْزِلَتِهِ فِي الْقَتْلِ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ الْمُسْلِمِ يَجْرَحُ الْيَهُودِيَّ أَوِ النَّصْرَانِيَّ إِنَّ سَيِّدَ الْعَبْدِ إِنْ شَاءَ أَنْ يَعْقِلَ عَنْهُ مَا قَدْ أَصَابَ فَعَلَ أَوْ أَسْلَمَهُ فَيُبَاعُ فَيُعْطِي الْيَهُودِيَّ أَوِ النَّصْرَانِيَّ مِنْ ثَمَنِ الْعَبْدِ دِيَةَ جُرْحِهِ أَوْ ثَمَنَهُ كُلَّهُ إِنْ أَحَاطَ بِثَمَنِهِ وَلاَ يُعْطِي الْيَهُودِيَّ وَلاَ النَّصْرَانِيَّ عَبْدًا مُسْلِمًا ‏.‏\hadithno{1578}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he had heard that Marwan ibn al-Hakam gave a decision about a slave who was injured that the person who injured him had to pay what he had diminished of the value of the slave. Malik said, "What is done in our community is that for the head wound of a slave that bares the bone, there is a twentieth of his price. The head wound which splinters the bone is three twentieths of his price. Both the wound to the brain and the belly wound are a third of his price. Besides these four, any other types of injury that decrease the price of the slave are considered after the slave is better and well, and one sees what the value of the slave is after his injury and what his value whole was before he had the injury. Then the one who injured him pays the difference between the two values}}
\hadithdefcmd{malik}{1579}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، قَضَى أَنَّ دِيَةَ الْيَهُودِيِّ، أَوِ النَّصْرَانِيِّ - إِذَا قُتِلَ أَحَدُهُمَا - مِثْلُ نِصْفِ دِيَةِ الْحُرِّ الْمُسْلِمِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنْ لاَ يُقْتَلَ مُسْلِمٌ بِكَافِرٍ إِلاَّ أَنْ يَقْتُلَهُ مُسْلِمٌ قَتْلَ غِيْلَةٍ فَيُقْتَلُ بِهِ ‏.‏\hadithno{1579}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard that Umar ibn Abd al-Aziz gave a decision that when a jew or christian was killed, his blood-money was half the blood-money of a free muslim. Malik said, "What is done in our community, is that a muslim is not killed for a kafir unless the muslim kills him by deceit. Then he is killed for it}}
\hadithdefcmd{malik}{1580}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ، كَانَ يَقُولُ دِيَةُ الْمَجُوسِيِّ ثَمَانِي مِائَةِ دِرْهَمٍ ‏.‏ قَالَ مَالِكٌ وَهُوَ الأَمْرُ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ وَجِرَاحُ الْيَهُودِيِّ وَالنَّصْرَانِيِّ وَالْمَجُوسِيِّ فِي دِيَاتِهِمْ عَلَى حِسَابِ جِرَاحِ الْمُسْلِمِينَ فِي دِيَاتِهِمُ الْمُوضِحَةُ نِصْفُ عُشْرِ دِيَتِهِ وَالْمَأْمُومَةُ ثُلُثُ دِيَتِهِ وَالْجَائِفَةُ ثُلُثُ دِيَتِهِ فَعَلَى حِسَابِ ذَلِكَ جِرَاحَاتُهُمْ كُلُّهَا ‏.‏\hadithno{1580}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Sulayman ibn Yasar said, "The blood-money of a magian is eight hundred dirhams." Malik said, "This is what is done in our community." Malik said, "The blood-monies of the jew, christian, and magian in their injuries, is according to the injury of the muslims in their blood-moneys. The head wound is a twentieth of his full blood-money. The wound that opens the head is a third of his blood-money. The belly-wound is a third of his blood-money. All their injuries are according to this calculation}}
\hadithdefcmd{malik}{1581}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ لَيْسَ عَلَى الْعَاقِلَةِ عَقْلٌ فِي قَتْلِ الْعَمْدِ إِنَّمَا عَلَيْهِمْ عَقْلُ قَتْلِ الْخَطَإِ ‏.‏\hadithno{1581}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "The tribe is not obliged to pay blood-money for intentional murder. They pay blood-money for accidental killing}}
\hadithdefcmd{malik}{1582}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ مَضَتِ السُّنَّةُ أَنَّ الْعَاقِلَةَ لاَ تَحْمِلُ شَيْئًا مِنْ دِيَةِ الْعَمْدِ إِلاَّ أَنْ يَشَاءُوا ذَلِكَ ‏.‏ وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، مِثْلَ ذَلِكَ ‏\hadithno{1582}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "The precedent of the sunna is that the tribe are not liable for any blood- money of an intentional killing unless they wish that." Yahya related to me from Malik from Yahya ibn Said the same as that}}
\hadithdefcmd{malik}{1584}{قَالَ مَالِكٌ إِنَّ ابْنَ شِهَابٍ قَالَ مَضَتِ السُّنَّةُ فِي قَتْلِ الْعَمْدِ حِينَ يَعْفُو أَوْلِيَاءُ الْمَقْتُولِ أَنَّ الدِّيَةَ تَكُونُ عَلَى الْقَاتِلِ فِي مَالِهِ خَاصَّةً إِلاَّ أَنْ تُعِينَهُ الْعَاقِلَةُ عَنْ طِيبِ نَفْسٍ مِنْهَا ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا أَنَّ الدِّيَةَ لاَ تَجِبُ عَلَى الْعَاقِلَةِ حَتَّى تَبْلُغَ الثُّلُثَ فَصَاعِدًا فَمَا بَلَغَ الثُّلُثَ فَهُوَ عَلَى الْعَاقِلَةِ وَمَا كَانَ دُونَ الثُّلُثِ فَهُوَ فِي مَالِ الْجَارِحِ خَاصَّةً ‏.‏ قَالَ مَالِكٌ الأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا فِيمَنْ قُبِلَتْ مِنْهُ الدِّيَةُ فِي قَتْلِ الْعَمْدِ أَوْ فِي شَىْءٍ مِنَ الْجِرَاحِ الَّتِي فِيهَا الْقِصَاصُ أَنَّ عَقْلَ ذَلِكَ لاَ يَكُونُ عَلَى الْعَاقِلَةِ إِلاَّ أَنْ يَشَاءُوا وَإِنَّمَا عَقْلُ ذَلِكَ فِي مَالِ الْقَاتِلِ أَوِ الْجَارِحِ خَاصَّةً إِنْ وُجِدَ لَهُ مَالٌ فَإِنْ لَمْ يُوجَدْ لَهُ مَالٌ كَانَ دَيْنًا عَلَيْهِ وَلَيْسَ عَلَى الْعَاقِلَةِ مِنْهُ شَىْءٌ إِلاَّ أَنْ يَشَاءُوا ‏.‏ قَالَ مَالِكٌ وَلاَ تَعْقِلُ الْعَاقِلَةُ أَحَدًا أَصَابَ نَفْسَهُ عَمْدًا أَوْ خَطَأً بِشَىْءٍ وَعَلَى ذَلِكَ رَأْىُ أَهْلِ الْفِقْهِ عِنْدَنَا وَلَمْ أَسْمَعْ أَنَّ أَحَدًا ضَمَّنَ الْعَاقِلَةَ مِنْ دِيَةِ الْعَمْدِ شَيْئًا وَمِمَّا يُعْرَفُ بِهِ ذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏فَمَنْ عُفِيَ لَهُ مِنْ أَخِيهِ شَىْءٌ فَاتِّبَاعٌ بِالْمَعْرُوفِ وَأَدَاءٌ إِلَيْهِ بِإِحْسَانٍ‏\}‏ فَتَفْسِيرُ ذَلِكَ - فِيمَا نُرَى وَاللَّهُ أَعْلَمُ - أَنَّهُ مَنْ أُعْطِيَ مِنْ أَخِيهِ شَىْءٌ مِنَ الْعَقْلِ فَلْيَتْبَعْهُ بِالْمَعْرُوفِ وَلْيُؤَدِّ إِلَيْهِ بِإِحْسَانٍ ‏.‏ قَالَ مَالِكٌ فِي الصَّبِيِّ الَّذِي لاَ مَالَ لَهُ وَالْمَرْأَةِ الَّتِي لاَ مَالَ لَهَا إِذَا جَنَى أَحَدُهُمَا جِنَايَةً دُونَ الثُّلُثِ إِنَّهُ ضَامِنٌ عَلَى الصَّبِيِّ وَالْمَرْأَةِ فِي مَالِهِمَا خَاصَّةً إِنْ كَانَ لَهُمَا مَالٌ أُخِذَ مِنْهُ وَإِلاَّ فَجِنَايَةُ كُلِّ وَاحِدٍ مِنْهُمَا دَيْنٌ عَلَيْهِ لَيْسَ عَلَى الْعَاقِلَةِ مِنْهُ شَىْءٌ وَلاَ يُؤْخَذُ أَبُو الصَّبِيِّ بِعَقْلِ جِنَايَةِ الصَّبِيِّ وَلَيْسَ ذَلِكَ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا الَّذِي لاَ اخْتِلاَفَ فِيهِ أَنَّ الْعَبْدَ إِذَا قُتِلَ كَانَتْ فِيهِ الْقِيمَةُ يَوْمَ يُقْتَلُ وَلاَ تَحْمِلُ عَاقِلَةُ قَاتِلِهِ مِنْ قِيمَةِ الْعَبْدِ شَيْئًا قَلَّ أَوْ كَثُرَ وَإِنَّمَا ذَلِكَ عَلَى الَّذِي أَصَابَهُ فِي مَالِهِ خَاصَّةً بَالِغًا مَا بَلَغَ وَإِنْ كَانَتْ قِيمَةُ الْعَبْدِ الدِّيَةَ أَوْ أَكْثَرَ فَذَلِكَ عَلَيْهِ فِي مَالِهِ وَذَلِكَ لأَنَّ الْعَبْدَ سِلْعَةٌ مِنَ السِّلَعِ ‏.‏\hadithno{1584}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik said that Ibn Shihab said, "The precedent of the sunna in the intentional murder is that when the relatives of the murdered person relinquish retaliation, the blood-money is owed by the murderer from his own property unless the tribe helps him with it willingly." Malik said, "What is done in our community is that the blood- money is not obliged against the tribe until it has reached a third of the full amount and upwards. Whatever reaches a third is against the tribe, and whatever is below a third, is against the property of the one who did the injury." Malik said, "The way of doing things about which there is no dispute among us, in the case of someone who has the blood-money accepted from him in intentional murder or in any injury in which there is retaliation, is that that blood-money is not due from the tribe unless they wish it. The blood-money for that is from the property of the murderer or the injurer if he has property. If he does not have any property, it is a debt against him, and none of it is owed by the tribe unless they wish." Malik said, "The tribe does not pay blood-money to anyone who injures himself, intentionally or accidentally. This is the opinion of the people of fiqh in our community. I have not heard that anyone has made the tribe liable for any blood-money incurred by intentional acts. Part of what is well-known of that is that Allah, the Blessed, and the Exalted, said in His Book, 'Whoever has something pardoned him by his brother, should follow it with what is accepted and pay it with good will' (Sura 2 ayat 178) The commentary on that - in our view - and Allah knows best, is that whoever gives his brother something of the blood- money, should follow it with what is accepted and pay him with good will." Malik spoke about a child who had no property and a woman who had no property. He said, "When one of them causes an injury below a third of the blood-money, it is taken on behalf of the child and woman from their personal property, if they have property from which it may be taken. If not, the injury which each of them has caused is a debt against them. The tribe does not have to pay any of it and the father of a child is not liable for the blood-money of an injury caused by the child and he is not responsible for it." Malik said, "The way of doing things in our community about which there is no dispute, is that when a slave is killed, the value for him is that of the day on which he was killed. The tribe of the murderer is not liable for any of the value of the slave, great or small. That is the responsibility of the one who struck him from his own personal property as far as it covers. If the value of the slave is the blood- money or more, that is against him in his property. That is because the slave is a certain type of goods}}
\hadithdefcmd{malik}{1585}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، نَشَدَ النَّاسَ بِمِنًى مَنْ كَانَ عِنْدَهُ عِلْمٌ مِنَ الدِّيَةِ أَنْ يُخْبِرَنِي ‏.‏ فَقَامَ الضَّحَّاكُ بْنُ سُفْيَانَ الْكِلاَبِيُّ فَقَالَ كَتَبَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أُوَرِّثَ امْرَأَةَ أَشْيَمَ الضِّبَابِيِّ مِنْ دِيَةِ زَوْجِهَا ‏.‏ فَقَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ ادْخُلِ الْخِبَاءَ حَتَّى آتِيَكَ فَلَمَّا نَزَلَ عُمَرُ بْنُ الْخَطَّابِ أَخْبَرَهُ الضَّحَّاكُ فَقَضَى بِذَلِكَ عُمَرُ بْنُ الْخَطَّابِ ‏.‏ قَالَ ابْنُ شِهَابٍ وَكَانَ قَتْلُ أَشْيَمَ خَطَأً ‏.‏\hadithno{1585}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Umar ibn al- Khattab demanded of the people at Mina, "If anyone has knowledge of blood-money, let him inform me." Ad-Dahhak ibn Sufyan al-Kilabi stood up and said, "The Messenger of Allah, may Allah bless him and grant him peace, wrote to me that the wife of Ashyam ad-Dibabi inherited from the blood-money of her husband." Umar ibn al-Khattab said to him, "Go into the tent until I come to you." When Umar ibn al-Khattab came in, ad-Dahhak told him about it and Umar ibn al-Khattab gave a decision based on that. Ibn Shihab said, "The killing of Ashyam was accidental}}
\hadithdefcmd{malik}{1586}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ رَجُلاً، مِنْ بَنِي مُدْلِجٍ - يُقَالُ لَهُ قَتَادَةُ - حَذَفَ ابْنَهُ بِالسَّيْفِ فَأَصَابَ سَاقَهُ فَنُزِيَ فِي جُرْحِهِ فَمَاتَ فَقَدِمَ سُرَاقَةُ بْنُ جُعْشُمٍ عَلَى عُمَرَ بْنِ الْخَطَّابِ فَذَكَرَ ذَلِكَ لَهُ فَقَالَ لَهُ عُمَرُ اعْدُدْ عَلَى مَاءِ قُدَيْدٍ عِشْرِينَ وَمِائَةَ بَعِيرٍ حَتَّى أَقْدَمَ عَلَيْكَ فَلَمَّا قَدِمَ إِلَيْهِ عُمَرُ بْنُ الْخَطَّابِ أَخَذَ مِنْ تِلْكَ الإِبِلِ ثَلاَثِينَ حِقَّةً وَثَلاَثِينَ جَذَعَةً وَأَرْبَعِينَ خَلِفَةً ثُمَّ قَالَ أَيْنَ أَخُو الْمَقْتُولِ قَالَ هَا أَنَا ذَا ‏.‏ قَالَ خُذْهَا فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ لِقَاتِلٍ شَىْءٌ ‏"‏ ‏.‏\hadithno{1586}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Yahya ibn Said from Amr ibn Shuayb that a man of the Banu Mudlij called Qatada threw a sword at his son and it struck his thigh. The wound bled profusely and he died. Suraqa ibn Jusham came to Umar ibn al-Khattab and mentioned that to him Umar said to him, "At the watering place of Qudayd count one hundred and twenty camels and wait until I come to you." When Umar ibn al-Khattab came to him, he took thirty four-year-old camels, thirty five-year-old camels, and forty pregnant camels from them. Then he said, "Where is the brother of the slain man?" He said, "Here." He said, "Take them. The Messenger of Allah, may Allah bless him and grant him peace, said, 'The killer gets nothing}}
\hadithdefcmd{malik}{1587}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلاَ أَتُغَلَّظُ الدِّيَةُ فِي الشَّهْرِ الْحَرَامِ فَقَالاَ لاَ وَلَكِنْ يُزَادُ فِيهَا لِلْحُرْمَةِ ‏.‏ فَقِيلَ لِسَعِيدٍ هَلْ يُزَادُ فِي الْجِرَاحِ كَمَا يُزَادُ فِي النَّفْسِ فَقَالَ نَعَمْ ‏.‏ قَالَ مَالِكٌ أُرَاهُمَا أَرَادَا مِثْلَ الَّذِي صَنَعَ عُمَرُ بْنُ الْخَطَّابِ فِي عَقْلِ الْمُدْلِجِيِّ حِينَ أَصَابَ ابْنَهُ ‏.‏\hadithno{1587}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik said that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar were asked, "Does one deal more harshly in taking the blood-money in the sacred month?" They said, "No. But it is increased in it because of violating the month." It was said to Said, "Does one increase for the wound as one increases for the life?" He said, "Yes." Malik added, "I think that they meant the same as what Umar ibn al-Khattab did with respect to the blood-money of the Mudliji when he struck his son." (i.e. giving 120 camels instead of)}}
\hadithdefcmd{malik}{1588}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ - يُقَالُ لَهُ أُحَيْحَةُ بْنُ الْجُلاَحِ - كَانَ لَهُ عَمٌّ صَغِيرٌ هُوَ أَصْغَرُ مِنْ أُحَيْحَةَ وَكَانَ عِنْدَ أَخْوَالِهِ فَأَخَذَهُ أُحَيْحَةُ فَقَتَلَهُ فَقَالَ أَخْوَالُهُ كُنَّا أَهْلَ ثُمِّهِ وَرُمِّهِ حَتَّى إِذَا اسْتَوَى عَلَى عُمَمِهِ غَلَبَنَا حَقُّ امْرِئٍ فِي عَمِّهِ ‏.‏ قَالَ عُرْوَةُ فَلِذَلِكَ لاَ يَرِثُ قَاتِلٌ مَنْ قَتَلَ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ قَاتِلَ الْعَمْدِ لاَ يَرِثُ مِنْ دِيَةِ مَنْ قَتَلَ شَيْئًا وَلاَ مِنْ مَالِهِ وَلاَ يَحْجُبُ أَحَدًا وَقَعَ لَهُ مِيرَاثٌ وَأَنَّ الَّذِي يَقْتُلُ خَطَأً لاَ يَرِثُ مِنَ الدِّيَةِ شَيْئًا وَقَدِ اخْتُلِفَ فِي أَنْ يَرِثَ مِنْ مَالِهِ لأَنَّهُ لاَ يُتَّهَمُ عَلَى أَنَّهُ قَتَلَهُ لِيَرِثَهُ وَلِيَأْخُذَ مَالَهُ فَأَحَبُّ إِلَىَّ أَنْ يَرِثَ مِنْ مَالِهِ وَلاَ يَرِثُ مِنْ دِيَتِهِ ‏.‏\hadithno{1588}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Urwa ibn az- Zubayr that a man of the Ansar called Uhayha ibn al-Julah had a young paternal uncle who was younger than him and who was living with his maternal uncles. Uhayha took him and killed him. His maternal uncles said, "We brought him up from a baby to a youth till he stood firm on his feet, and we have had the right of a man taken from us by his paternal uncle." Urwa said, "For that reason a killer does not inherit from the one he killed." Malik said, "The way of doing things about which there is no dispute is that the intentional murderer does not inherit anything of the blood-money of the person he has murdered or any of his property. He does not stop anyone who has a share of inheritance from inheriting. The one who kills accidentally does not inherit anything of the blood-money and there is dispute as to whether or not he inherits from the dead person's property because there is no suspicion that he killed him for his inheritance and in order to take his property. I prefer that he inherit from the dead person's property and not inherit from the blood-money}}
\hadithdefcmd{malik}{1589}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ جَرْحُ الْعَجْمَاءِ جُبَارٌ وَالْبِئْرُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏\hadithno{1589}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab and Abu Salama ibn Abd ar-Rahman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The wound of an animal is of no account and no compensation is due for it. The well is of no account and no compensation is due for it. The mine is of no account and no compensation is due for it and a fifth is due for buried treasures." (Al-kanz:see Book 17). Malik said, "Everyone leading an animal by the halter, driving it, and riding it is responsible for what the animal strikes unless the animal kicks out without anything being done to it to make it kick out. Umar ibn al-Khattab imposed the blood-money on a person who was exercising his horse." Malik said, "It is more fitting that a person leading an animal by the halter, driving it, or riding it incur a loss than a person who is exercising his horse." (See hadith 4 of this book). Malik said, "What is done in our community about a person who digs a well on a road or ties up an animal or does the like of that on a road used by muslims, is that since what he has done is included in that which he is not permitted to do in such a place, he is liable for whatever injury or other thing arises from that action. The blood-money of that which is less than a third of the full blood- money is owed from his own personal property. Whatever reaches a third or more, is owed by his tribe. Any such things that he does which he is permitted to do on the muslims' road are something for which he has no liability or loss. Part of that is a hole which a man digs to collect rain, and the beast from which the man alights for some need and leaves standing on the road. There is no penalty against anyone for this." Malik spoke about a man who went down a well, and another man followed behind him, and the lower one pulled the higher one and they fell into the well and both died He said, "The tribe of the one who pulled him in is responsible for the blood-money." Malik spoke about a child whom a man ordered to go down into a well or to climb a palm tree and he died as a result. He said, "The one who ordered him is liable for whatever befalls him, be it death or something else." Malik said, "The way of doing things in our community about which there is no dispute is that women and children are not obliged to pay blood-money together with the tribe in the blood-moneys which the tribe must pay. The blood-money is only obligatory for a man who has reached puberty." Malik said that the tribe could bind themselves to the blood-money of mawali if they wished. If they refused, they were people of the diwan or were cut off from their people. In the time of the Messenger of Allah, may Allah bless him and grant him peace, people paid the blood-money to each other as well as in the time of Abu Bakr as-Siddiq before there was a diwan. The diwan was in the time of Umar ibn al-Khattab. No one other than one's people and the ones holding the wala' paid blood- money for one because the wala' was not transferable and because the Prophet, may Allah bless him and grant him peace, said, "The wala' belongs to the one who sets free." Malik said, "The wala' is an established relationship." Malik said, "What is done in our community about animals that are injured is that the person who causes the injury pays whatever of their value has been diminished." Malik said about a man condemned to death and one of the other hudud befell him, "He is not punished for it. That is because the killing overrides all of that, except for slander. The slander remains hanging over the one to whom it was said because it will be said to him, 'Why do you not flog the one who slandered you?' I think that the condemned man is flogged with the hadd before he is killed, and then he is killed. I do not think that any retaliation is inflicted on him for any injury except killing because killing overrides all of that." Malik said, "What is done in our community is that when a murdered person is found among the main body of a people in a village or other place, the house or place of the nearest people to him is not responsible. That is because the murdered person can be slain and then cast at the door of some people to shame them by it. No one is responsible for the like of that." Malik said about a group of people who fight with each other and when the fight is broken up, a man is found dead or wounded, and it is not known who did it, "The best of what is heard about that is that there is blood-money for him, and the blood-money is against the people who argued with him. If the injured or slain person is not from either of the two parties, his blood-money is against both of the two parties together}}
\hadithdefcmd{malik}{1590}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَتَلَ نَفَرًا خَمْسَةً أَوْ سَبْعَةً بِرَجُلٍ وَاحِدٍ قَتَلُوهُ قَتْلَ غِيلَةٍ وَقَالَ عُمَرُ لَوْ تَمَالأَ عَلَيْهِ أَهْلُ صَنْعَاءَ لَقَتَلْتُهُمْ جَمِيعًا ‏.‏\hadithno{1590}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that Umar ibn al-Khattab killed five or seven people for one man whom they had killed secretly by trickery. Umar said, "Had all the people of Sana joined forces against him, I would have killed them all}}
\hadithdefcmd{malik}{1591}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، أَنَّهُ بَلَغَهُ أَنَّ حَفْصَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَتَلَتْ جَارِيَةً لَهَا سَحَرَتْهَا وَقَدْ كَانَتْ دَبَّرَتْهَا فَأَمَرَتْ بِهَا فَقُتِلَتْ ‏.‏ قَالَ مَالِكٌ السَّاحِرُ الَّذِي يَعْمَلُ السِّحْرَ وَلَمْ يَعْمَلْ ذَلِكَ لَهُ غَيْرُهُ هُوَ مَثَلُ الَّذِي قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى فِي كِتَابِهِ ‏\{‏وَلَقَدْ عَلِمُوا لَمَنِ اشْتَرَاهُ مَا لَهُ فِي الآخِرَةِ مِنْ خَلاَقٍ‏\}‏ فَأَرَى أَنْ يُقْتَلَ ذَلِكَ إِذَا عَمِلَ ذَلِكَ هُوَ نَفْسُهُ ‏.‏\hadithno{1591}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Abd ar-Rahman ibn Sad ibn Zurara that he had heard that Hafsa, the wife of the Prophet, may Allah bless him and grant him peace, killed one of her slave-girls who had used sorcery against her. She was a mudabbara. Hafsa gave the order, and she was killed. Malik said, "The sorcerer is the one who uses sorcery for himself and no one else uses that for him. It is like the one about whom Allah, the Blessed, the Exalted, said in His Book, 'They know the one who devotes himself to it will have no share in the Next World.' (Sura 2 ayat 102) I think that that person is killed if he does that himself}}
\hadithdefcmd{malik}{1592}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عُمَرَ بْنِ حُسَيْنٍ، مَوْلَى عَائِشَةَ بِنْتِ قُدَامَةَ أَنَّ عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، أَقَادَ وَلِيَّ رَجُلٍ مِنْ رَجُلٍ قَتَلَهُ بِعَصًا فَقَتَلَهُ وَلِيُّهُ بِعَصًا ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ الْمُجْتَمَعُ عَلَيْهِ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ الرَّجُلَ إِذَا ضَرَبَ الرَّجُلَ بِعَصًا أَوْ رَمَاهُ بِحَجَرٍ أَوْ ضَرَبَهُ عَمْدًا فَمَاتَ مِنْ ذَلِكَ فَإِنَّ ذَلِكَ هُوَ الْعَمْدُ وَفِيهِ الْقِصَاصُ ‏.‏ قَالَ مَالِكٌ فَقَتْلُ الْعَمْدِ عِنْدَنَا أَنْ يَعْمِدَ الرَّجُلُ إِلَى الرَّجُلِ فَيَضْرِبَهُ حَتَّى تَفِيظَ نَفْسُهُ وَمِنَ الْعَمْدِ أَيْضًا أَنْ يَضْرِبَ الرَّجُلُ الرَّجُلَ فِي النَّائِرَةِ تَكُونُ بَيْنَهُمَا ثُمَّ يَنْصَرِفُ عَنْهُ وَهُوَ حَىٌّ فَيُنْزَى فِي ضَرْبِهِ فَيَمُوتُ فَتَكُونُ فِي ذَلِكَ الْقَسَامَةُ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّهُ يُقْتَلُ فِي الْعَمْدِ الرِّجَالُ الأَحْرَارُ بِالرَّجُلِ الْحُرِّ الْوَاحِدِ وَالنِّسَاءُ بِالْمَرْأَةِ كَذَلِكَ وَالْعَبِيدُ بِالْعَبْدِ كَذَلِكَ ‏.‏\hadithno{1592}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Umar ibn Husayn, the mawla of A'isha bint Qudama, that Abd al-Malik ibn Marwan imposed retaliation against a man who killed a mawla with a stick and so the mawla's patron killed the man with a stick. Malik said, "The generally agreed on way of doing things in our community about which there is no dispute is that when a man strikes another man with a stick or hits him with a rock or intentionally strikes him causing his death, that is an intentional injury and there is retaliation for it." Malik said, "Intentional murder with us is that a man intentionally goes to a man and strikes him until his life goes. Part of intentional injury also is that a man strikes a man in a quarrel between them. He leaves him while he is alive, and he bleeds to death and so dies. There is retaliation for that." Malik said, "What is done in our community is that a group of free men are killed for the intentional murder of one free man, and a group of women for one woman, and a group of slaves for one slave}}
\hadithdefcmd{malik}{1593}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، كَتَبَ إِلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ يَذْكُرُ أَنَّهُ أُتِيَ بِسَكْرَانَ قَدْ قَتَلَ رَجُلاً فَكَتَبَ إِلَيْهِ مُعَاوِيَةُ أَنِ اقْتُلْهُ بِهِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ أَحْسَنُ مَا سَمِعْتُ فِي تَأْوِيلِ هَذِهِ الآيَةِ قَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏الْحُرُّ بِالْحُرِّ وَالْعَبْدُ بِالْعَبْدِ ‏\}‏ فَهَؤُلاَءِ الذُّكُورُ ‏\{‏وَالأُنْثَى بِالأُنْثَى‏\}‏ أَنَّ الْقِصَاصَ يَكُونُ بَيْنَ الإِنَاثِ كَمَا يَكُونُ بَيْنَ الذُّكُورِ وَالْمَرْأَةُ الْحُرَّةُ تُقْتَلُ بِالْمَرْأَةِ الْحُرَّةِ كَمَا يُقْتَلُ الْحُرُّ بِالْحُرِّ وَالأَمَةُ تُقْتَلُ بِالأَمَةِ كَمَا يُقْتَلُ الْعَبْدُ بِالْعَبْدِ وَالْقِصَاصُ يَكُونُ بَيْنَ النِّسَاءِ كَمَا يَكُونُ بَيْنَ الرِّجَالِ وَالْقِصَاصُ أَيْضًا يَكُونُ بَيْنَ الرِّجَالِ وَالنِّسَاءِ وَذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏وَكَتَبْنَا عَلَيْهِمْ فِيهَا أَنَّ النَّفْسَ بِالنَّفْسِ وَالْعَيْنَ بِالْعَيْنِ وَالأَنْفَ بِالأَنْفِ وَالأُذُنَ بِالأُذُنِ وَالسِّنَّ بِالسِّنِّ وَالْجُرُوحَ قِصَاصٌ ‏\}‏ فَذَكَرَ اللَّهُ تَبَارَكَ وَتَعَالَى أَنَّ النَّفْسَ بِالنَّفْسِ فَنَفْسُ الْمَرْأَةِ الْحُرَّةِ بِنَفْسِ الرَّجُلِ الْحُرِّ وَجُرْحُهَا بِجُرْحِهِ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يُمْسِكُ الرَّجُلَ لِلرَّجُلِ فَيَضْرِبُهُ فَيَمُوتُ مَكَانَهُ أَنَّهُ إِنْ أَمْسَكَهُ وَهُوَ يَرَى أَنَّهُ يُرِيدُ قَتْلَهُ قُتِلاَ بِهِ جَمِيعًا وَإِنْ أَمْسَكَهُ وَهُوَ يَرَى أَنَّهُ إِنَّمَا يُرِيدُ الضَّرْبَ مِمَّا يَضْرِبُ بِهِ النَّاسُ لاَ يَرَى أَنَّهُ عَمَدَ لِقَتْلِهِ فَإِنَّهُ يُقْتَلُ الْقَاتِلُ وَيُعَاقَبُ الْمُمْسِكُ أَشَدَّ الْعُقُوبَةِ وَيُسْجَنُ سَنَةً لأَنَّهُ أَمْسَكَهُ وَلاَ يَكُونُ عَلَيْهِ الْقَتْلُ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَقْتُلُ الرَّجُلَ عَمْدًا أَوْ يَفْقَأُ عَيْنَهُ عَمْدًا فَيُقْتَلُ الْقَاتِلُ أَوْ تُفْقَأُ عَيْنُ الْفَاقِئِ\hadithno{1593}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Marwan ibn al-Hakam wrote to Muawiya ibn Abi Sufyan to mention to him that a drunkard was brought to him who had killed a man. Muawiya wrote to him to kill him in retaliation for the dead man. Yahya said that Malik said, "The best of what I have heard on the interpretation of this ayat, the word of Allah, the Blessed, the Exalted, 'The free man for the free man and the slave for the slave - these are men and the woman for the woman,' (Sura 2 ayat 178) is that retaliation is between women as it is between men. The free woman is killed for the free woman as the free man is killed for the free man. The slave-girl is slain for the slave-girl as the slave is slain for the slave. Retaliation is between women as it is between men. That is because Allah, the Blessed, the Exalted, said in His Book, 'We have written for them in it that it is a life for a life and an eye for an eye, a nose for a nose, and an ear for an ear, and a tooth for a tooth, and for wounds there is retaliation.' (Sura 5 ayat 48) Allah, the Blessed, the Exalted, mentioned that it is a life for a life. It is the life of a free woman for the life of a free man, and her injury for his injury." Malik said about a man who held a man fast for another man to hit, and he died on the spot, "If he held him and he thought that he meant to kill him, the two of them are both killed for him. If he held him and he thought that he meant to beat him as people sometimes do, and he did not think that he meant to kill him, the murderer is slain and the one who held him is punished with a very severe punishment and jailed for a year. There is no killing against him." Malik said about a man who murdered a man intentionally or gouged out his eye intentionally, and then was slain or had his eye gouged out himself before retaliation was inflicted on him, "There is no blood-money nor retaliation against him. The right of the one who was killed or had his eye gouged out goes when the thing which he is claiming as retaliation goes. It is the same with a man who murders another man intentionally and then the murderer dies. When the murderer dies, the one seeking blood-revenge has nothing of blood- money or anything else. That is by the word of Allah, the Blessed the Exalted, 'Retaliation is written for you in killing. The free man for the free man and the slave for the slave.' " Malik said, "He only has retaliation against the one who killed him. If the man who murdered him dies, he has no retaliation or blood-money." Malik said, "There is no retaliation held against a free man by a slave for any injury. The slave is killed for the free man when he intentionally murders him. The free man is not slain for the slave, even if he murders him intentionally. It is the best of what I have heard}}
\hadithdefcmd{malik}{1594}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا بَكْرِ بْنَ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَقَادَ مِنْ كَسْرِ الْفَخِذِ ‏.‏\hadithno{1594}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he saw whomever he was satisfied with among the people of knowledge say about a man who willed that his murderer be pardoned when he murdered him intentionally, "That is permitted for him. He is more entitled to the man's blood than any of his relatives after him." Malik said about a man who pardoned murder, after he had claimed his right and it was obliged for him, "There is no blood-money against the murderer unless the one who pardons him stipulates that when he pardons him." Malik said about the murderer when he was pardoned, "He is flogged one hundred lashes and jailed for a year." Malik said, "When a man murders intentionally and there is a clear proof of that, and the murdered man has sons and daughters and the sons pardon and the daughters refuse to pardon, the pardon of the sons is permitted in opposition to the daughters and there is no authority for the daughters with the sons in demanding blood and pardoning}}
\hadithdefcmd{malik}{1595}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ سَائِبَةً، أَعْتَقَهُ بَعْضُ الْحُجَّاجِ فَقَتَلَ ابْنَ رَجُلٍ مِنْ بَنِي عَائِذٍ فَجَاءَ الْعَائِذِيُّ أَبُو الْمَقْتُولِ إِلَى عُمَرَ بْنِ الْخَطَّابِ يَطْلُبُ دِيَةَ ابْنِهِ فَقَالَ عُمَرُ لاَ دِيَةَ لَهُ ‏.‏ فَقَالَ الْعَائِذِيُّ أَرَأَيْتَ لَوْ قَتَلَهُ ابْنِي فَقَالَ عُمَرُ إِذًا تُخْرِجُونَ دِيَتَهُ فَقَالَ هُوَ إِذًا كَالأَرْقَمِ إِنْ يُتْرَكْ يَلْقَمْ وَإِنْ يُقْتَلْ يَنْقَمْ ‏.‏\hadithno{1595}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya said that Malik said, "The generally agreed on way of doing things in our community is that retaliation is taken from someone who breaks someone's hand or foot intentionally and not blood-money." Malik said, "Retaliation is not inflicted on anyone until the wound of the injured party has healed. Then retaliation is inflicted on him. If the wound of the person on whom the retaliation has been inflicted is like the first person's wound when it heals, it is retaliation. If the wound of the one on whom the retaliation has been inflicted becomes worse or he dies, there is nothing held against the one who has taken retaliation. If the wound of the person on whom the retaliation has been inflicted heals and the injured party is paralysed or his injury has healed but he has a scar, defect, or blemish, the person on whom the retaliation has been inflicted does not have his hand broken again and further retaliation is not taken for his injury." He said, "But there is blood-money from him according to what he has impaired or maimed of the hand of the injured party. The bodily injury is also like that." Malik said, "When a man intentionally goes to his wife and gouges out her eye or breaks her hand or cuts off her finger or such like, and does it intentionally, retaliation is inflicted on him. As for a man who strikes his wife with a rope or a whip and hits what he did not mean to hit or does what he did not intend to do, he pays blood-money for what he has struck according to this principle, and retaliation is not inflicted on him." Yahya related to me from Malik that he had heard that Abu Bakr ibn Muhammd ibn Amr ibn Hazm took retaliation for the breaking of a leg. Yahya related to me from Malik from Abu'z-Zinad from Sulayman ibn Yasar that a slave was set free by one of the people on hajj and his master had abandoned the right to inherit from him. The ex-slave then killed a man from the Banu A'idh tribe. An A'idhi, the father of the slain man came to Umar ibn al-Khattab seeking the blood-money of his son. Umar said, "He has no blood-money." The A'idhi said, "What would you think if it had been my son who killed him?" Umar said, "Then you would pay his blood-money." He said, "He is then like the black and white Arqam snake. If it is left, it devours and if it is killed, it takes revenge}}
